<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "Type de valeur METADATA invalide : \"%s\".",
"Saved" => "Sauvegardé",
"test email settings" => "tester les paramètres d'e-mail",
"If you received this email, the settings seem to be correct." => "Si vous recevez cet email, c'est que les paramètres sont corrects",
"A problem occurred while sending the e-mail. Please revisit your settings." => "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres.",
"Email sent" => "Email envoyé",
"You need to set your user email before being able to send test emails." => "Vous devez configurer votre e-mail d'utilisateur avant de pouvoir envoyer des e-mails de test.",
"Send mode" => "Mode d'envoi",
"Encryption" => "Chiffrement",
"Authentication method" => "Méthode d'authentification",
"Unable to load list from App Store" => "Impossible de charger la liste depuis l'App Store",
"Authentication error" => "Erreur d'authentification",
"Your full name has been changed." => "Votre nom complet a été modifié.",
"Unable to change full name" => "Impossible de changer le nom complet",
"Group already exists" => "Ce groupe existe déjà",
"Unable to add group" => "Impossible d'ajouter le groupe",
"Files decrypted successfully" => "Fichiers décryptés avec succès",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "Impossible de décrypter vos fichiers, veuillez vérifier votre owncloud.log ou demander à votre administrateur",
"Couldn't decrypt your files, check your password and try again" => "Impossible de décrypter vos fichiers, vérifiez votre mot de passe et essayez à nouveau",
"Encryption keys deleted permanently" => "Clés de chiffrement définitivement supprimées.",
"Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" => "Impossible de supprimer définitivement vos clés de chiffrement, merci de regarder journal owncloud.log ou de demander à votre administrateur",
"Couldn't remove app." => "Impossible de supprimer l'application.",
"Email saved" => "E-mail sauvegardé",
"Invalid email" => "E-mail invalide",
"Unable to delete group" => "Impossible de supprimer le groupe",
"Unable to delete user" => "Impossible de supprimer l'utilisateur",
"Backups restored successfully" => "La sauvegarde a été restaurée avec succès",
"Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" => "Impossible de restaurer vos clés de chiffrement, merci de regarder journal owncloud.log ou de demander à votre administrateur",
"Language changed" => "Langue changée",
"Invalid request" => "Requête invalide",
"Admins can't remove themself from the admin group" => "Les administrateurs ne peuvent pas se retirer eux-mêmes du groupe admin",
"Unable to add user to group %s" => "Impossible d'ajouter l'utilisateur au groupe %s",
"Unable to remove user from group %s" => "Impossible de supprimer l'utilisateur du groupe %s",
"Couldn't update app." => "Impossible de mettre à jour l'application",
"Wrong password" => "Mot de passe incorrect",
"No user supplied" => "Aucun utilisateur fourni",
"Please provide an admin recovery password, otherwise all user data will be lost" => "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données de l'utilisateur seront perdues",
"Wrong admin recovery password. Please check the password and try again." => "Mot de passe administrateur de récupération de données non valable. Veuillez vérifier le mot de passe et essayer à nouveau.",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "L'infrastructure d'arrière-plan ne permet pas la modification de mot de passe, mais la clef de chiffrement des utilisateurs a été mise à jour avec succès.",
"Unable to change password" => "Impossible de modifier le mot de passe",
"Sending..." => "Envoi en cours...",
"User Documentation" => "Documentation utilisateur",
"Admin Documentation" => "Documentation administrateur",
"Update to {appversion}" => "Mettre à jour vers {appversion}",
"Uninstall App" => "Désinstaller l'application",
"Disable" => "Désactiver",
"Enable" => "Activer",
"Please wait...." => "Veuillez patienter…",
"Error while disabling app" => "Erreur lors de la désactivation de l'application",
"Error while enabling app" => "Erreur lors de l'activation de l'application",
"Updating...." => "Mise à jour...",
"Error while updating app" => "Erreur lors de la mise à jour de l'application",
"Error" => "Erreur",
"Update" => "Mettre à jour",
"Updated" => "Mise à jour effectuée avec succès",
"Uninstalling ...." => "Désintallation...",
"Error while uninstalling app" => "Erreur lors de la désinstallation de l'application",
"Uninstall" => "Désinstaller",
"Select a profile picture" => "Selectionner une photo de profil ",
"Very weak password" => "Mot de passe de très faible sécurité",
"Weak password" => "Mot de passe de faible sécurité",
"So-so password" => "Mot de passe de sécurité tout juste acceptable",
"Good password" => "Mot de passe de sécurité suffisante",
"Strong password" => "Mot de passe de forte sécurité",
"Decrypting files... Please wait, this can take some time." => "Déchiffrement en cours... Cela peut prendre un certain temps.",
"Delete encryption keys permanently." => "Supprimer définitivement les clés de chiffrement",
"Restore encryption keys." => "Restaurer les clés de chiffrement",
"Unable to delete {objName}" => "Impossible de supprimer {objName}",
"Error creating group" => "Erreur lors de la création du groupe",
"A valid group name must be provided" => "Vous devez spécifier un nom de groupe valide",
"deleted {groupName}" => "{groupName} supprimé",
"undo" => "annuler",
"Groups" => "Groupes",
"Group Admin" => "Admin Groupe",
"Delete" => "Supprimer",
"never" => "jamais",
"deleted {userName}" => "{userName} supprimé",
"add group" => "ajouter un groupe",
"A valid username must be provided" => "Un nom d'utilisateur valide doit être saisi",
"Error creating user" => "Erreur lors de la création de l'utilisateur",
"A valid password must be provided" => "Un mot de passe valide doit être saisi",
"Warning: Home directory for user \"{user}\" already exists" => "Attention : Le dossier Home pour l'utilisateur \"{user}\" existe déjà",
"__language_name__" => "Français",
"Everything (fatal issues, errors, warnings, info, debug)" => "Tout (erreurs fatales, erreurs, avertissements, informations, debogage)",
"Info, warnings, errors and fatal issues" => "Informations, avertissements, erreurs et erreurs fatales",
"Warnings, errors and fatal issues" => "Avertissements, erreurs et erreurs fatales",
"Errors and fatal issues" => "Erreurs et erreurs fatales",
"Fatal issues only" => "Erreurs fatales uniquement",
"None" => "Aucun",
"Login" => "Connexion",
"Plain" => "En clair",
"NT LAN Manager" => "Gestionnaire du réseau NT",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "Avertissement de sécurité",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "Vous accédez à %s via HTTP. Nous vous recommandons fortement de configurer votre serveur pour forcer l'utilisation de HTTPS à la place.",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Votre dossier de données et vos fichiers sont probablement accessibles depuis internet. Le fichier .htaccess ne fonctionne pas. Nous vous recommandons vivement de configurer votre serveur web de façon à ce que ce dossier de données ne soit plus accessible, ou bien de le déplacer à l'extérieur de la racine du serveur web.",
"Setup Warning" => "Avertissement, problème de configuration",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Votre serveur web, n'est pas correctement configuré pour permettre la synchronisation des fichiers, car l'interface WebDav ne fonctionne pas comme il faut.",
"Please double check the <a href=\"%s\">installation guides</a>." => "Veuillez consulter à nouveau les <a href=\"%s\">guides d'installation</a>.",
"PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." => "PHP est apparemment configuré pour supprimer les blocs de documentation internes. Cela rendra plusieurs applications de base inaccessibles.",
"This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." => "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
"Database Performance Info" => "Performances de la base de données",
"SQLite is used as database. For larger installations we recommend to change this. To migrate to another database use the command line tool: 'occ db:convert-type'" => "SQLite est utilisée comme base de donnée. Pour des installations plus volumineuse, nous vous conseillons de changer ce réglage. Pour migrer vers une autre base de donnée, utilisez la commande : \"occ db:convert-type\"",
"Module 'fileinfo' missing" => "Module 'fileinfo' manquant",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir de meilleurs résultats pour la détection des types de fichiers.",
"Your PHP version is outdated" => "Votre version de PHP est trop ancienne",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "Votre version de PHP est trop ancienne. Nous vous recommandons fortement de migrer vers une version 5.3.8 ou plus récente encore, car les versions antérieures sont réputées problématiques. Il est possible que cette installation ne fonctionne pas correctement.",
"Locale not working" => "Localisation non fonctionnelle",
"System locale can not be set to a one which supports UTF-8." => "Les paramètres régionaux ne peuvent pas être configurés avec prise en charge d'UTF-8.",
"This means that there might be problems with certain characters in file names." => "Cela signifie qu'il pourrait y avoir des problèmes avec certains caractères dans les noms de fichier.",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Nous conseillons vivement d'installer les paquets requis sur votre système pour supporter l'un des paramètres régionaux suivants : %s.",
"Internet connection not working" => "La connexion internet ne fonctionne pas",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Ce serveur ne peut se connecter à internet. Cela signifie que certaines fonctionnalités, telles que le montage de supports de stockage distants, les notifications de mises à jour ou l'installation d'applications tierces ne fonctionneront pas. L'accès aux fichiers à distance, ainsi que les notifications par mails ne seront pas fonctionnels également. Il est recommandé d'activer la connexion internet pour ce serveur si vous souhaitez disposer de l'ensemble des fonctionnalités offertes.",
"Cron" => "Cron",
"Last cron was executed at %s." => "Le dernier cron s'est exécuté à la date suivante : %s.",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "Le dernier cron s'est exécuté à la date suivante : %s. Cela fait plus d'une heure, quelque chose a du mal se passer.",
"Cron was not executed yet!" => "Le cron n'a pas encore été exécuté !",
"Execute one task with each page loaded" => "Exécute une tâche à chaque chargement de page",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "cron.php est enregistré en tant que service webcron pour appeler cron.php toutes les 15 minutes via http.",
"Use system's cron service to call the cron.php file every 15 minutes." => "Utilisez le service cron du système pour appeler le fichier cron.php toutes les 15 minutes.",
"Sharing" => "Partage",
"Allow apps to use the Share API" => "Autoriser les applications à utiliser l'API de partage",
"Allow users to share via link" => "Autoriser les utilisateurs à partager par lien",
"Enforce password protection" => "Obliger la protection par mot de passe",
"Allow public uploads" => "Autoriser les téléversements publics",
"Set default expiration date" => "Spécifier la date d'expiration par défaut",
"Expire after " => "Expiration après ",
"days" => "jours",
"Enforce expiration date" => "Imposer la date d'expiration",
"Allow resharing" => "Autoriser le repartage",
"Restrict users to only share with users in their groups" => "N'autoriser les partages qu'entre membres de même groupes",
"Allow users to send mail notification for shared files" => "Autoriser les utilisateurs à envoyer des notifications par courriel concernant les partages",
"Exclude groups from sharing" => "Empêcher certains groupes de partager",
"These groups will still be able to receive shares, but not to initiate them." => "Ces groupes ne pourront plus initier de partage, mais ils pourront toujours rejoindre les partages faits par d'autres. ",
"Security" => "Sécurité",
"Enforce HTTPS" => "Forcer HTTPS",
"Forces the clients to connect to %s via an encrypted connection." => "Forcer les clients à se connecter à %s via une connexion chiffrée.",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "Veuillez vous connecter à cette instance %s via HTTPS pour activer ou désactiver SSL.",
"Email Server" => "Serveur mail",
"This is used for sending out notifications." => "Ceci est utilisé pour l'envoi des notifications.",
"From address" => "Adresse source",
"mail" => "courriel",
"Authentication required" => "Authentification requise",
"Server address" => "Adresse du serveur",
"Port" => "Port",
"Credentials" => "Informations d'identification",
"SMTP Username" => "Nom d'utilisateur SMTP",
"SMTP Password" => "Mot de passe SMTP",
"Test email settings" => "Tester les paramètres e-mail",
"Send email" => "Envoyer un e-mail",
"Log" => "Log",
"Log level" => "Niveau de log",
"More" => "Plus",
"Less" => "Moins",
"Version" => "Version",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Développé par la <a href=\"http://ownCloud.org/contact\" target=\"_blank\">communauté ownCloud</a>, le <a href=\"https://github.com/owncloud\" target=\"_blank\">code source</a> est publié sous license <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Ajoutez votre application",
"More Apps" => "Plus d'applications…",
"Select an App" => "Sélectionner une Application",
"Documentation:" => "Documentation :",
"See application page at apps.owncloud.com" => "Voir la page des applications à l'url apps.owncloud.com",
"See application website" => "Voir le site web de l'application",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "Distribué sous licence <span class=\"licence\"></span>, par <span class=\"author\"></span>",
"Enable only for specific groups" => "Activer uniquement pour certains groupes",
"All" => "Tous",
"Administrator Documentation" => "Documentation administrateur",
"Online Documentation" => "Documentation en ligne",
"Forum" => "Forum",
"Bugtracker" => "Suivi de bugs",
"Commercial Support" => "Support commercial",
"Get the apps to sync your files" => "Obtenez les applications de synchronisation de vos fichiers",
"Show First Run Wizard again" => "Revoir le premier lancement de l'installeur",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Vous avez utilisé <strong>%s</strong> des <strong>%s<strong> disponibles",
"Password" => "Mot de passe",
"Your password was changed" => "Votre mot de passe a été changé",
"Unable to change your password" => "Impossible de changer votre mot de passe",
"Current password" => "Mot de passe actuel",
"New password" => "Nouveau mot de passe",
"Change password" => "Changer de mot de passe",
"Full Name" => "Nom complet",
"Email" => "Adresse mail",
"Your email address" => "Votre adresse e-mail",
"Fill in an email address to enable password recovery and receive notifications" => "Saisissez votre adresse mail pour permettre la réinitialisation du mot de passe et la réception des notifications",
"Profile picture" => "Photo de profil",
"Upload new" => "Nouvelle depuis votre ordinateur",
"Select new from Files" => "Nouvelle depuis les Fichiers",
"Remove image" => "Supprimer l'image",
"Either png or jpg. Ideally square but you will be able to crop it." => "Format png ou jpg. Idéalement carrée, mais vous pourrez la recadrer.",
"Your avatar is provided by your original account." => "Votre avatar est fourni par votre compte original.",
"Cancel" => "Annuler",
"Choose as profile image" => "Choisir en tant que photo de profil ",
"Language" => "Langue",
"Help translate" => "Aidez à traduire",
"The encryption app is no longer enabled, please decrypt all your files" => "L'app de chiffrement n’est plus activée, veuillez déchiffrer tous vos fichiers",
"Log-in password" => "Mot de passe de connexion",
"Decrypt all Files" => "Déchiffrer tous les fichiers",
"Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." => "Vos clés de chiffrement ont été déplacées dans l'emplacement de backup. Si quelque chose devait mal se passer, vous pouvez restaurer les clés. Choisissez la suppression permanente seulement si vous êtes sûr que tous les fichiers ont été déchiffrés correctement.",
"Restore Encryption Keys" => "Restaurer les clés de chiffrement",
"Delete Encryption Keys" => "Supprimer les clés de chiffrement",
"Login Name" => "Nom d'utilisateur",
"Create" => "Créer",
"Admin Recovery Password" => "Récupération du mot de passe administrateur",
"Enter the recovery password in order to recover the users files during password change" => "Entrez le mot de passe de récupération pour récupérer les fichiers utilisateurs pendant le changement de mot de passe",
"Search Users and Groups" => "Chercher parmi les utilisateurs et groupes",
"Add Group" => "Ajouter un groupe",
"Group" => "Groupe",
"Everyone" => "Tout le monde",
"Admins" => "Administrateurs",
"Default Quota" => "Quota par défaut",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "Veuillez entrer le quota de stockage (ex. \"512 MB\" ou \"12 GB\")",
"Unlimited" => "Illimité",
"Other" => "Autre",
"Username" => "Nom d'utilisateur",
"Quota" => "Quota",
"Storage Location" => "Emplacement du Stockage",
"Last Login" => "Dernière Connexion",
"change full name" => "Modifier le nom complet",
"set new password" => "Changer le mot de passe",
"Default" => "Défaut",
"Connectivity Checks" => "Vérification de la connectivité",
"No problems found" => "Aucun problème trouvé",
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
